![Continuous integration](https://github.com/mbraak/django-file-form/workflows/Continuous%20integration/badge.svg) [![Version](https://badge.fury.io/py/django-file-form.svg)](https://pypi.python.org/pypi/django-file-form/)

[![codecov](https://codecov.io/gh/mbraak/django-file-form/branch/master/graph/badge.svg?token=vyiybGWB54)](https://codecov.io/gh/mbraak/django-file-form)

[![License](https://img.shields.io/pypi/l/django-file-form.svg)](https://pypi.python.org/pypi/django-file-form/)

# Django file form

**Django-file-form** helps you to write forms with a pretty ajax upload.

Read the documentation at [http://mbraak.github.io/django-file-form/](http://mbraak.github.io/django-file-form/)

Features:

- You can easily add an ajax file-upload to a form.
- The ajax upload works the same as an html upload.
  - This means that you don't have to change your code to support ajax upload.
- Supports single and multiple file upload.
- Supports edition of uploaded files.
- Supports upload directly to AWS S3 compatible storages.
- Supports frontend events for the addition and removal of files.
- Supports addition of arbitrary file meta data and related widgets.

The project is hosted on [github](https://github.com/mbraak/django-file-form).
